# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .created_field import CreatedField

__all__ = ["CreatedFieldListResponse"]

CreatedFieldListResponse: TypeAlias = List[CreatedField]
